#!/usr/bin/python3
# SilentTimer Action Figure adjust calibration value
# 
# 17.03.2022
# Copyright (C) 2022 Balthasar Szczepanski
# 
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
# 
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
# 
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

import subprocess
import os
import datetime
import sys

# PORT = '/dev/ttyS4'
BASE_PATH = os.path.dirname(os.path.abspath(__file__))
STAF_TIMESTAMP = os.path.join(BASE_PATH, 'staf-timestamp')
LOG_FILE = os.path.join(BASE_PATH, 'timestamp.txt')
STAF_TIMERATE = os.path.join(BASE_PATH, 'staf-timerate.m')
STAF_ADJUST = os.path.join(BASE_PATH, 'staf-adjust')
STAF_RESYNC = os.path.join(BASE_PATH, 'staf-resync')

if len(sys.argv) > 1:
	port = sys.argv[1]
else:
	print('missing port name.', file = sys.stderr)

if len(sys.argv) > 2:
	log_file  = sys.argv[2]
else:
	log_file = LOG_FILE

new_log = False
try:
	with open(log_file, 'r', encoding='utf-8') as f:
		line = f.readline()
		if line.strip() == '':
			new_log = True
		else:
			time_str = line.strip()
			time_split = time_str.split(' ')
			time_comp_1 = datetime.datetime.fromtimestamp(float(time_split[0]))
except:
	new_log = True


cmd = [STAF_TIMESTAMP, port]
process = subprocess.run(cmd, encoding='utf-8', capture_output=True)

if process.returncode != 0:
	sys.exit(process.returncode)

time_str = process.stdout.strip()
time_split = time_str.split(' ')
time_comp = datetime.datetime.fromtimestamp(float(time_split[0]))
time_staf = datetime.datetime.utcfromtimestamp(float(time_split[1]))
time_diff = abs((time_staf - time_comp).total_seconds())
if new_log:
	time_diff_1 = time_diff
else:
	time_diff_1 = (time_comp - time_comp_1).total_seconds()
	print ('ORIG: ' + str(time_comp_1))

print ('COMP: ' + str(time_comp))
print ('STAF: ' + str(time_staf))

if (time_diff < 15 and time_diff_1 < (60 * 60 * 24 * 7 * 4)) or new_log:
	with open(log_file, 'a', encoding='utf-8') as f:
		print(time_str, file=f)
else:
	print ('readjust')
	
	cmd = [STAF_TIMERATE, log_file]
	process = subprocess.run(cmd, encoding='utf-8', capture_output=True)
	if process.returncode != 0:
		sys.exit(process.returncode)
	A = process.stdout.strip()
	
	with open(log_file, 'w', encoding='utf-8') as f:
		pass
	
	cmd = [STAF_ADJUST, port]
	process = subprocess.run(cmd, encoding='utf-8', input=A, capture_output=False)
	if process.returncode != 0:
		sys.exit(process.returncode)
	
	cmd = [STAF_RESYNC, port]
	process = subprocess.run(cmd, encoding='utf-8', capture_output=False)
	if process.returncode != 0:
		sys.exit(process.returncode)
