// SilentTimer Action Figure get timestamps
// 
// 18.12.2020
// Copyright (C) 2020 Balthasar Szczepanski
// 
// This program is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
// 
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with this program.  If not, see <http://www.gnu.org/licenses/>.

#include <time.h>
#include <stdio.h>
#include <stdint.h>
#include <inttypes.h>
#include "libstaf.h"

int main(int argc, char *argv[])
{
	int fd;
	int r,r2;
	
	uint16_t year;
	uint8_t mon, day, h, m, s, cs;
	
	struct timespec comptime;
	struct tm staftm;
	time_t staftime;
	uint16_t stafms, compms;
	
	if (argc<2)
		return 0;
	
	fd = stafConnect(argv[1]);
	if (fd<1)
	{
		fprintf(stderr,"%d: Can't connect to %s.\n",fd,argv[1]);
		return fd;
	}
	
	r = stafGetTime(fd, NULL, &cs, &s, &m, &h, &day, &mon, &year);
	r2 = clock_gettime(CLOCK_REALTIME,&comptime);
	if (r)
	{
		fprintf(stderr,"%d: Can't get STAF time.\n",r);
		stafDisconnect(fd);
		return r;
	}
	if (r2)
	{
		fprintf(stderr,"%d: Can't get computer time.\n",r2);
		stafDisconnect(fd);
		return r2;
	}
	
	staftm.tm_year = (int)(year-1900);
	staftm.tm_mon  = (int)(mon-1);
	staftm.tm_mday = (int)day;
	staftm.tm_hour = (int)h;
	staftm.tm_min  = (int)m;
	staftm.tm_sec  = (int)s;
	staftime = timegm(&staftm);
	stafms = 10 * ((uint16_t)cs);
	compms = (uint16_t)(comptime.tv_nsec/1000000);
	
	printf ("%"PRIuMAX".%03"PRIu16" %"PRIuMAX".%03"PRIu16"\n",(uintmax_t)(comptime.tv_sec),compms,(uintmax_t)staftime,stafms);
	
	r = stafDisconnect(fd);
	return r;
}
